/*
 * Common SDRAM configuration.
 *
 * Copyright (C) 1996, 1997 by Ralf Baechle
 *
 * Copyright (C) 2009 Qi Hardware Inc.
 * Authors: Xiangfu Liu <xiangfu@openmobilefree.net>
 *
 * Copyright (C) 2015, 2016 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __SDRAM_H__
#define __SDRAM_H__

/*
 * RAM configuration
 */
#define CONFIG_SYS_SDRAM_BASE		0x80000000

/*
 * SDRAM configuration (timings in ns)
 */
#ifdef CONFIG_CPU_JZ4730_MINIPC
#define SDRAM_BW16			0	/* Data bus width: 0-32bit, 1-16bit */
#else
#define SDRAM_BW16			1	/* Data bus width: 0-32bit, 1-16bit */
#endif

#define SDRAM_BANK4			1	/* Banks each chip: 0-2bank, 1-4bank */
#define SDRAM_ROW			13	/* Row address: 11 to 13 */
#define SDRAM_COL			9	/* Column address: 8 to 12 */
#define SDRAM_CASL			2	/* CAS latency: 2 or 3 */
#define SDRAM_TRAS			45	/* RAS# Active Time */
#define SDRAM_RCD			20	/* RAS# to CAS# Delay */
#define SDRAM_TPC			20	/* RAS# Precharge Time */
#define SDRAM_TRWL			7	/* Write Latency Time */

#ifdef CONFIG_CPU_JZ4730_MINIPC
#define SDRAM_TREF			7812	/* Refresh period: 8192 cycles/64ms */
#else
#define SDRAM_TREF			15625	/* Refresh period: 8192 cycles/64ms */
#endif

#define SDRAM_ROW0			11	/* Row address minimum */
#define SDRAM_COL0			8	/* Column address minimum */
#define SDRAM_BANK40			0	/* Bank minimum */

/*
 * Cache configuration
 */
#define CONFIG_SYS_DCACHE_SIZE		16384
#define CONFIG_SYS_ICACHE_SIZE		16384
#define CONFIG_SYS_CACHELINE_SIZE	32

#define Index_Invalidate_I		0x00
#define Index_Writeback_Inv_D		0x01
#define Index_Store_Tag_I		0x08
#define Index_Store_Tag_D		0x09
#define Hit_Writeback_Inv_D		0x15

#define CONFIG_CM_UNCACHED		2
#define CONFIG_CM_CACHABLE_NONCOHERENT	3

/*
 * Memory configuration
 */
#define KSEG0				0x80000000
#define PAGE_SIZE			4096

#endif /* __SDRAM_H__ */
